<h3>{$title_section}</h3>
<p>{$admin_nav}</p>
{if $message!=''}<p>{$message}</p>{/if}
{$startform}
	<div class="pageoverflow">
		<p class="pagetext">{$title_sing_loudly}:</p>
		<p class="pageinput">{$input_sing_loudly}</p>
	</div>
	<div class="pageoverflow">
		<p class="pagetext">&nbsp;</p>
		<p class="pageinput">{$submit}</p>
	</div>
{$endform}
