<?php
$lang['friendlyname'] = 'Frontend User Listing';
$lang['postinstall'] = 'Post Install Message, e.g., Be sure to set "Use Skeletons" permissions to use this module!';
$lang['postuninstall'] = 'Post Uninstall Message, e.g., "Curses! Foiled Again!"';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['error'] = 'Error!';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['title_mod_prefs'] = 'Module Preferences';
$lang['title_mod_admin'] = 'Module Admin Panel';
$lang['title_admin_panel'] = 'Frontend User Listing Module';

$lang['submit'] = 'Submit';
$lang['summarytemplate'] = 'Summary Template';

$lang['moddescription'] = 'This extention to the Frontend Users module shows Front End User listing in the front end.';
$lang['welcome_text'] = '<p>This extention to the Frontend Users module shows Front End User listing in the front end.  More to be added here...</p>';
$lang['changelog'] = '<ul><li>Version 0.1. 20 December 2005. Alpha Release.</li></ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>It shows Front End User listing in the front end.</p>
<h3>How Do I Use It</h3>
<p>Placing the module in a page or template using the smarty tag &#123;cms_module module=\'FrontEndUserListing\' category=\'CATEGORY_NAME\'}</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the
module homepage at <a href="http://www.cmsmodules.com">CMSModules.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2005, Victor Katolyk <a href="mailto:katonchik@gmail.com">&lt;katonchik@gmail.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>
